Statistics
==========

.. toctree::
   :maxdepth: 1

   sage/stats/basic_stats
   sage/stats/intlist
   sage/stats/hmm/hmm
   sage/stats/hmm/chmm
   sage/stats/hmm/distributions
   sage/stats/hmm/util

   sage/stats/distributions/discrete_gaussian_integer
   sage/stats/distributions/discrete_gaussian_polynomial
   sage/stats/distributions/discrete_gaussian_lattice

   sage/stats/r

.. include:: ../footer.txt
